﻿using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace P9_2
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        //Экран справки
        HelpScreen help;
        Texture2D helpBack;
        Texture2D helpText;
        //Экран меню
        MenuScreen menu;
        Texture2D menuBack;
        Texture2D menuGameName;
        Texture2D menuTxtStartGame;
        Texture2D menuTxtHelp;
        Texture2D menuTxtExit;
        //Текущий элемент меню
        int currentItem;
        //Интервал задержки переключения между элементами меню
        int interval;
        //Игровой экран
        GameScreen newGame;
        Texture2D gameBat;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            //При запуске игры активным устанавливается первый элемент меню
            currentItem = 1;
            interval = 0;
            base.Initialize();
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            //Загружаем элементы игры и создаем игровые экраны
            spriteBatch = new SpriteBatch(GraphicsDevice);
            Services.AddService(typeof(SpriteBatch), spriteBatch);
            helpBack = Content.Load<Texture2D>("helpBack");
            helpText = Content.Load<Texture2D>("helpText");
            help = new HelpScreen(this, helpBack, helpText,
                new Rectangle(0, 0, this.Window.ClientBounds.Width, this.Window.ClientBounds.Height),
                new Rectangle((this.Window.ClientBounds.Width - helpText.Width)/2, 
                (this.Window.ClientBounds.Height - helpText.Height)/2, 
                helpText .Width , helpText .Height ));
            Components.Add(help);
            gameBat = Content.Load<Texture2D>("BallandBats");
            newGame = new GameScreen(this, ref gameBat, new Rectangle(18, 9, 17, 88), 
                new Vector2(100, 100));
            Components.Add(newGame);
            menuBack = Content.Load<Texture2D>("menuBack");
            menuGameName = Content.Load<Texture2D>("menuGameName");
            menuTxtStartGame = Content.Load<Texture2D>("menuTxtStartGame");
            menuTxtHelp = Content.Load<Texture2D>("menuTxtHelp");
            menuTxtExit = Content.Load<Texture2D>("menuTxtExit");
            menu = new MenuScreen(this, menuBack, menuGameName, menuTxtStartGame, menuTxtHelp,
                menuTxtExit, new Rectangle(100, 300, 400, 50), new Rectangle(100, 350, 400, 50), 
                new Rectangle(100, 400, 400, 50));
            Components.Add(menu);
            //Отображаем меню, остальные элементы скрыты
            menu.Show();
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        /// 
        //Обработка нажатий на клавиши
        void KeyboardHandle()
        {
            //считаем состояние клавиатуры
              KeyboardState kbState = Keyboard.GetState();
            //Если прошло 4 игровых цикла
            interval ++;
            if (interval >=4)
            {
                //Обнуляем счетичик
                interval = 0;

                //Если выбран экран меню
                if (menu.Enabled)
                {
                    //Если нажата клавиша вверх
                    if (kbState.IsKeyDown(Keys.Up))
                    {
                        //Уменьшить на 1 счетчик, отвечающий за
                        //смену пунктов меню
                        currentItem--;
                        //Если в момент нажатия был активен самый верхний
                        //пункт
                        if (currentItem < 1)
                        {   
                            //Делаем текущим третий пункт
                            currentItem = 3;
                            //Вызов процедуры для отображения смены пункта меню
                            menu.GetKey(currentItem);
                        }
                            //если при уменьшении номера пункта
                            //он не меньше 1, вызываем процедуру
                            //отображения смены пункта
                        else
                        {
                            menu.GetKey(currentItem);
                        }
                    }
                    //При нажатии клавиши вниз
                    if (kbState.IsKeyDown(Keys.Down))
                    {
                        //Увеличим счетчик
                        currentItem++;
                        //Если он больше 3 - активируем первый пункт
                        if (currentItem > 3)
                        {
                            currentItem = 1;
                            menu.GetKey(currentItem);
                        }
                            //Если не меньше 3 - переходим на следующий пункт
                        else
                        {
                            menu.GetKey(currentItem);
                        }
                    }
                    //При нажатии клавиши Enter
                    //выполняем команду, соответствующую текущему пункту меню
                    if (kbState .IsKeyDown (Keys .Enter))
                    {
                        //Первый пункт - скрываем экран меню
                        //и отображаем игровой экран
                        if (currentItem == 1)
                        {
                            menu.Hide();
                            newGame.Show();
                        }
                        //Скрываем меню и
                        //отображаем экран справки
                        if (currentItem ==2) 
                        {
                            menu.Hide();
                            help.Show ();
                        }
                        //Выходим из игры
                        if (currentItem == 3)
                        {
                            this.Exit();
                        }
                    }
                 

                }
            }
            //Если активен экран справки
                if (help.Enabled)
                {
                    //При нажатии Esc закрываем экран справки
                    //И открываем меню
                    if (kbState.IsKeyDown(Keys.Escape))
                    {
                        help.Hide();
                        menu.Show();
                    }
                }
            //Если активен игровой экран
            //При нажатии Esc закрываем его 
            //и открываем меню
            //Обработка нажатий клавиш, необходимых для работы игрового экрана
            //проводится в объекте, соответствующем этому экрану
                if (newGame.Enabled)
                {
                    if (kbState.IsKeyDown(Keys.Escape))
                    {
                        newGame.Hide();
                        menu.Show();
                    }
                }
        }

        protected override void Update(GameTime gameTime)
        {
            //Обработка нажатий на клавиши
            KeyboardHandle();
            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            graphics.GraphicsDevice.Clear(Color.CornflowerBlue);
            spriteBatch.Begin();
            base.Draw(gameTime);
            spriteBatch.End();
        }
    }
}
